@@ -1,5 +1,6 @@
+/* $Id: keycontrol.c 4 2008-06-22 09:19:11Z rbock $ */
 /* GtkDatabox - An extension to the gtk+ library
- * Copyright (C) 1998 - 2007  Dr. Roland Bock
+ * Copyright (C) 1998 - 2008  Dr. Roland Bock
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
@@ -174,7 +175,7 @@ create_basics (void)
    gtk_databox_graph_add (GTK_DATABOX (box), graph);
 
    g_signal_connect (GTK_OBJECT (box), "key_press_event",
-		     GTK_SIGNAL_FUNC (key_press_cb), graph);
+		     G_CALLBACK (key_press_cb), graph);
 
    gtk_databox_auto_rescale (GTK_DATABOX (box), 0.05);
 
