@@ -1031,6 +1031,10 @@ gtk_databox_calculate_translation_factors (GtkDatabox * box)
       box->priv->translation_factor_x =
 	 widget->allocation.width / (box->priv->visible_right -
 				box->priv->visible_left);
+   else if (box->priv->scale_type_x == GTK_DATABOX_SCALE_LOG2)
+      box->priv->translation_factor_x =
+	 widget->allocation.width / log2 (box->priv->visible_right /
+				    box->priv->visible_left);
    else
       box->priv->translation_factor_x =
 	 widget->allocation.width / log10 (box->priv->visible_right /
@@ -1040,6 +1044,10 @@ gtk_databox_calculate_translation_factors (GtkDatabox * box)
       box->priv->translation_factor_y =
 	 widget->allocation.height / (box->priv->visible_bottom -
 				 box->priv->visible_top);
+   else if (box->priv->scale_type_y == GTK_DATABOX_SCALE_LOG2)
+      box->priv->translation_factor_y =
+	 widget->allocation.height / log2 (box->priv->visible_bottom /
+				     box->priv->visible_top);
    else
       box->priv->translation_factor_y =
 	 widget->allocation.height / log10 (box->priv->visible_bottom /
@@ -1609,6 +1617,9 @@ gtk_databox_get_offset_x (GtkDatabox* box)
    if (box->priv->scale_type_x == GTK_DATABOX_SCALE_LINEAR)
       return (box->priv->visible_left - box->priv->total_left)
 	 / (box->priv->total_right - box->priv->total_left);
+   else if (box->priv->scale_type_x == GTK_DATABOX_SCALE_LOG2)
+      return log2 (box->priv->visible_left / box->priv->total_left)
+	 / log2 (box->priv->total_right / box->priv->total_left);
    else
       return log10 (box->priv->visible_left / box->priv->total_left)
 	 / log10 (box->priv->total_right / box->priv->total_left);
@@ -1620,6 +1631,9 @@ gtk_databox_get_page_size_x (GtkDatabox* box)
    if (box->priv->scale_type_x == GTK_DATABOX_SCALE_LINEAR)
       return (box->priv->visible_left - box->priv->visible_right)
 	 / (box->priv->total_left - box->priv->total_right);
+   else if (box->priv->scale_type_x == GTK_DATABOX_SCALE_LOG2)
+      return log2 (box->priv->visible_left / box->priv->visible_right)
+	 / log2 (box->priv->total_left / box->priv->total_right);
    else
       return log10 (box->priv->visible_left / box->priv->visible_right)
 	 / log10 (box->priv->total_left / box->priv->total_right);
@@ -1631,6 +1645,9 @@ gtk_databox_get_offset_y (GtkDatabox* box)
    if (box->priv->scale_type_y == GTK_DATABOX_SCALE_LINEAR)
       return (box->priv->visible_top - box->priv->total_top)
 	 / (box->priv->total_bottom - box->priv->total_top);
+   else if (box->priv->scale_type_y == GTK_DATABOX_SCALE_LOG2)
+      return log2 (box->priv->visible_top / box->priv->total_top)
+	 / log2 (box->priv->total_bottom / box->priv->total_top);
    else
       return log10 (box->priv->visible_top / box->priv->total_top)
 	 / log10 (box->priv->total_bottom / box->priv->total_top);
@@ -1642,6 +1659,9 @@ gtk_databox_get_page_size_y (GtkDatabox* box)
    if (box->priv->scale_type_y == GTK_DATABOX_SCALE_LINEAR)
       return (box->priv->visible_top - box->priv->visible_bottom)
 	 / (box->priv->total_top - box->priv->total_bottom);
+   else if (box->priv->scale_type_y == GTK_DATABOX_SCALE_LOG2)
+      return log2 (box->priv->visible_top / box->priv->visible_bottom)
+	 / log2 (box->priv->total_top / box->priv->total_bottom);
    else
       return log10 (box->priv->visible_top / box->priv->visible_bottom)
 	 / log10 (box->priv->total_top / box->priv->total_bottom);
@@ -1959,6 +1979,10 @@ gtk_databox_values_to_pixels (GtkDatabox * box, guint len,
 	 pixels->x =
 	    (*values_x -
 	     box->priv->visible_left) * box->priv->translation_factor_x;
+      else if (box->priv->scale_type_x == GTK_DATABOX_SCALE_LOG2)
+	 pixels->x =
+	    log2 (*values_x / box->priv->visible_left) *
+	    box->priv->translation_factor_x;
       else
 	 pixels->x =
 	    log10 (*values_x / box->priv->visible_left) *
@@ -1968,6 +1992,10 @@ gtk_databox_values_to_pixels (GtkDatabox * box, guint len,
 	 pixels->y =
 	    (*values_y -
 	     box->priv->visible_top) * box->priv->translation_factor_y;
+      else if (box->priv->scale_type_y == GTK_DATABOX_SCALE_LOG2)
+	 pixels->y =
+	    log2 (*values_y / box->priv->visible_top) *
+	    box->priv->translation_factor_y;
       else
 	 pixels->y =
 	    log10 (*values_y / box->priv->visible_top) *
@@ -1992,6 +2020,9 @@ gtk_databox_value_to_pixel_x (GtkDatabox * box, gfloat value)
       return (value -
 	      box->priv->visible_left) *
 	 box->priv->translation_factor_x;
+   else if (box->priv->scale_type_x == GTK_DATABOX_SCALE_LOG2)
+      return log2 (value / box->priv->visible_left) *
+	 box->priv->translation_factor_x;
    else
       return log10 (value / box->priv->visible_left) *
 	 box->priv->translation_factor_x;
@@ -2013,6 +2044,9 @@ gtk_databox_value_to_pixel_y (GtkDatabox * box, gfloat value)
    if (box->priv->scale_type_y == GTK_DATABOX_SCALE_LINEAR)
       return (value -
 	      box->priv->visible_top) * box->priv->translation_factor_y;
+   else if (box->priv->scale_type_y == GTK_DATABOX_SCALE_LOG2)
+      return log2 (value / box->priv->visible_top) *
+	 box->priv->translation_factor_y;
    else
       return log10 (value / box->priv->visible_top) *
 	 box->priv->translation_factor_y;
@@ -2034,6 +2068,11 @@ gtk_databox_pixel_to_value_x (GtkDatabox * box, gint16 pixel)
    if (box->priv->scale_type_x == GTK_DATABOX_SCALE_LINEAR)
       return box->priv->visible_left +
 	 pixel / box->priv->translation_factor_x;
+   else if (box->priv->scale_type_x == GTK_DATABOX_SCALE_LOG2)
+      return box->priv->visible_left * pow (2,
+					       pixel /
+					       box->priv->
+					       translation_factor_x);
    else
       return box->priv->visible_left * pow (10,
 					       pixel /
@@ -2057,6 +2096,11 @@ gtk_databox_pixel_to_value_y (GtkDatabox * box, gint16 pixel)
    if (box->priv->scale_type_y == GTK_DATABOX_SCALE_LINEAR)
       return box->priv->visible_top +
 	 pixel / box->priv->translation_factor_y;
+   else if (box->priv->scale_type_y == GTK_DATABOX_SCALE_LOG2)
+      return box->priv->visible_top * pow (2,
+					      pixel /
+					      box->priv->
+					      translation_factor_y);
    else
       return box->priv->visible_top * pow (10,
 					      pixel /
