@@ -23,6 +23,8 @@ static void gtk_databox_grid_real_draw (GtkDataboxGraph * grid,
 					GtkDatabox* box);
 static GdkGC* gtk_databox_grid_real_create_gc (GtkDataboxGraph * graph,
 					     GtkDatabox* box);
+static   gfloat *hline_vals=NULL;
+static   gfloat *vline_vals=NULL;
 
 /* IDs of properties */
 enum
@@ -215,6 +217,35 @@ gtk_databox_grid_new (gint hlines, gint vlines, GdkColor * color, guint size)
    return GTK_DATABOX_GRAPH (grid);
 }
 
+/**
+ * gtk_databox_grid_array_new:
+ * @hlines: number of horizontal lines in the grid
+ * @vlines: number of vertical lines in the grid
+ * @hline_vals: a pointer to an array of gfloat horizontal grid coordinate
+ * @vline_vals: a pointer to an array of gfloat vertical grid coordinate
+ * @color: color of the grid
+ * @size: line width of the grid
+ *
+ * Creates a new #GtkDataboxGrid object which can be added to a #GtkDatabox widget as nice decoration for other graphs.
+ *
+ * Return value: A new #GtkDataboxGrid object
+ **/
+GtkDataboxGraph *gtk_databox_grid_array_new (gint hlines, gint vlines, gfloat * local_hline_vals, gfloat * local_vline_vals,
+					  GdkColor * color, guint size)
+{
+   GtkDataboxGrid *grid;
+
+   grid = g_object_new (GTK_DATABOX_TYPE_GRID,
+			"color", color,
+			"size", size,
+			"grid-hlines", hlines, "grid-vlines", vlines, "grid-hline-vals", NULL);
+			//"grid-hlines", hlines, "grid-vlines", vlines, "grid-hline-vals", hline_vals, "grid-vline-vals", vline_vals, NULL);
+   hline_vals = local_hline_vals;
+   vline_vals = local_vline_vals;
+
+   return GTK_DATABOX_GRAPH (grid);
+}
+
 static void
 gtk_databox_grid_real_draw (GtkDataboxGraph * graph,
 			    GtkDatabox* box)
@@ -259,19 +290,36 @@ gtk_databox_grid_real_draw (GtkDataboxGraph * graph,
    factor_y =
       (bottom - top) / (grid->priv->hlines + 1);
 
-   for (i = 0; i < grid->priv->hlines; i++)
-   {
-      y = offset_y + (i + 1) * factor_y;
-      pixel_y = gtk_databox_value_to_pixel_y (box, y);
-      gdk_draw_line (pixmap, gc, 0, pixel_y, width, pixel_y);
-   }
+   if (hline_vals == NULL)
+      for (i = 0; i < grid->priv->hlines; i++)
+      {
+         y = offset_y + (i + 1) * factor_y;
+         pixel_y = gtk_databox_value_to_pixel_y (box, y);
+         gdk_draw_line (pixmap, gc, 0, pixel_y, width, pixel_y);
+      }
+   else
+      for (i = 0; i < grid->priv->hlines; i++)
+      {
+         y = hline_vals[i];
+         pixel_y = gtk_databox_value_to_pixel_y (box, y);
+         gdk_draw_line (pixmap, gc, 0, pixel_y, width, pixel_y);
+      }
+
+   if (vline_vals == NULL)
+      for (i = 0; i < grid->priv->vlines; i++)
+      {
+         x = offset_x + (i + 1) * factor_x;
+         pixel_x = gtk_databox_value_to_pixel_x (box, x);
+         gdk_draw_line (pixmap, gc, pixel_x, 0, pixel_x, height);
+      }
+   else
+      for (i = 0; i < grid->priv->vlines; i++)
+      {
+         x = vline_vals[i];
+         pixel_x = gtk_databox_value_to_pixel_x (box, x);
+         gdk_draw_line (pixmap, gc, pixel_x, 0, pixel_x, height);
+      }
 
-   for (i = 0; i < grid->priv->vlines; i++)
-   {
-      x = offset_x + (i + 1) * factor_x;
-      pixel_x = gtk_databox_value_to_pixel_x (box, x);
-      gdk_draw_line (pixmap, gc, pixel_x, 0, pixel_x, height);
-   }
 
    return;
 }
