@@ -571,6 +571,16 @@ gtk_databox_ruler_draw_ticks (GtkDataboxRuler * ruler)
       upper = ruler->priv->upper;
       lower = ruler->priv->lower;
    }
+   else if (ruler->priv->scale_type == GTK_DATABOX_SCALE_LOG2)
+   {
+      if (ruler->priv->upper <= 0 || ruler->priv->lower <= 0)
+      {
+	 g_warning
+	    ("For logarithmic scaling, the visible limits must by larger than 0!");
+      }
+      upper = log2 (ruler->priv->upper);
+      lower = log2 (ruler->priv->lower);
+   }
    else
    {
       if (ruler->priv->upper <= 0 || ruler->priv->lower <= 0)
@@ -617,6 +627,10 @@ gtk_databox_ruler_draw_ticks (GtkDataboxRuler * ruler)
       }
       subd_incr = digit * pow (10, power);
    }
+   else if (ruler->priv->scale_type == GTK_DATABOX_SCALE_LOG2)
+   {
+      subd_incr = 1.;
+   }
    else
    {
       subd_incr = 1.;
@@ -655,6 +669,9 @@ gtk_databox_ruler_draw_ticks (GtkDataboxRuler * ruler)
 
 	 g_snprintf (unit_str, ruler->priv->max_length + 1, format_string, cur);
       }
+      else if (ruler->priv->scale_type == GTK_DATABOX_SCALE_LOG2)
+	 g_snprintf (unit_str, ruler->priv->max_length + 1, format_string,
+		     pow (2, cur));
       else
 	 g_snprintf (unit_str, ruler->priv->max_length + 1, format_string,
 		     pow (10, cur));
@@ -686,6 +703,20 @@ gtk_databox_ruler_draw_ticks (GtkDataboxRuler * ruler)
 	 {
 	    pos = ROUND ((cur - lower + subd_incr / 5 * i) * increment);
 
+	    if (ruler->priv->orientation == GTK_ORIENTATION_HORIZONTAL)
+	       cairo_rectangle (cr,
+				pos, height + ythickness - length / 2,
+				1, length / 2);
+	    else
+	       cairo_rectangle (cr,
+				width + xthickness - length / 2, pos,
+				length / 2, 1);
+	 }
+      else  if (ruler->priv->scale_type == GTK_DATABOX_SCALE_LOG2)
+	 for (i = 1; i < 8; ++i)
+	 {
+	    pos = ROUND ((cur - lower + log2 (i)) * increment);
+
 	    if (ruler->priv->orientation == GTK_ORIENTATION_HORIZONTAL)
 	       cairo_rectangle (cr,
 				pos, height + ythickness - length / 2,
